@@ -26,7 +26,6 @@
 #include <rest/oauth-proxy.h>
 #include <json-glib/json-glib.h>
 
-#include "goalogging.h"
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
 #include "goaoauthprovider.h"
@@ -196,10 +195,10 @@ get_identity_sync (GoaOAuthProvider  *provider,
                                    rest_proxy_call_get_payload_length (call),
                                    &identity_error))
     {
-      goa_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
-                   identity_error->message,
-                   g_quark_to_string (identity_error->domain),
-                   identity_error->code);
+      g_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
+                 identity_error->message,
+                 g_quark_to_string (identity_error->domain),
+                 identity_error->code);
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -211,7 +210,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
   json_object = json_object_get_object_member (json_object, "user");
   if (json_object == NULL)
     {
-      goa_warning ("Did not find user in JSON data");
+      g_warning ("Did not find user in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -221,7 +220,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
   id = g_strdup (json_object_get_string_member (json_object, "id"));
   if (id == NULL)
     {
-      goa_warning ("Did not find user.id in JSON data");
+      g_warning ("Did not find user.id in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -231,7 +230,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
   json_object = json_object_get_object_member (json_object, "username");
   if (json_object == NULL)
     {
-      goa_warning ("Did not find user.username in JSON data");
+      g_warning ("Did not find user.username in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -241,7 +240,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
   presentation_identity = g_strdup (json_object_get_string_member (json_object, "_content"));
   if (presentation_identity == NULL)
     {
-      goa_warning ("Did not find user.username._content in JSON data");
+      g_warning ("Did not find user.username._content in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
